==> helm-annotations-3.6.0-sources.jar: io/dekorate/helm/config/ValuesSchemaProperty.java <==
package io.dekorate.helm.config;

import java.lang.Integer;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class ValuesSchemaProperty{
  public ValuesSchemaProperty() {
  }
  public ValuesSchemaProperty(String name,String description,String type,Integer minimum,Integer maximum,String pattern,Boolean required) {
    this.name = name;
    this.description = description;
    this.type = type;
    this.minimum = minimum;
    this.maximum = maximum;
    this.pattern = pattern;
    this.required = required;
  }
  private String name;
  private String description;
  private String type;
  private Integer minimum;
  private Integer maximum;
  private String pattern;
  private Boolean required;
  public String getName() {
    return this.name;
  }
  public String getDescription() {
    return this.description;
  }
  public String getType() {
    return this.type;
  }
  public Integer getMinimum() {
    return this.minimum;
  }
  public Integer getMaximum() {
    return this.maximum;
  }
  public String getPattern() {
    return this.pattern;
  }
  public Boolean getRequired() {
    return this.required;
  }
  public boolean isRequired() {
    return this.required != null &&  this.required;
  }
  public static ValuesSchemaPropertyBuilder newBuilder() {
    return new ValuesSchemaPropertyBuilder();
  }
  public static ValuesSchemaPropertyBuilder newBuilderFromDefaults() {
    return new ValuesSchemaPropertyBuilder().withType("string").withMinimum(-2147483648).withMaximum(2147483647).withRequired(false);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ValuesSchemaProperty that = (ValuesSchemaProperty) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (minimum != null ? !minimum.equals(that.minimum) :that.minimum != null) return false;
    if (maximum != null ? !maximum.equals(that.maximum) :that.maximum != null) return false;
    if (pattern != null ? !pattern.equals(that.pattern) :that.pattern != null) return false;
    if (required != null ? !required.equals(that.required) :that.required != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  description,  type,  minimum,  maximum,  pattern,  required,  super.hashCode());
  }
  
}

==> helm-annotations-4.0.0-sources.jar: io/dekorate/helm/config/ValuesSchemaProperty.java <==
package io.dekorate.helm.config;

import java.lang.Integer;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(builderPackage = "io.fabric8.kubernetes.api.builder")
  public class ValuesSchemaProperty{
  public ValuesSchemaProperty() {
  }
  public ValuesSchemaProperty(String name,String description,String type,Integer minimum,Integer maximum,String pattern,Boolean required) {
    this.name = name;
    this.description = description;
    this.type = type;
    this.minimum = minimum;
    this.maximum = maximum;
    this.pattern = pattern;
    this.required = required;
  }
  private String name;
  private String description;
  private String type;
  private Integer minimum;
  private Integer maximum;
  private String pattern;
  private Boolean required;
  public String getName() {
    return this.name;
  }
  public String getDescription() {
    return this.description;
  }
  public String getType() {
    return this.type;
  }
  public Integer getMinimum() {
    return this.minimum;
  }
  public Integer getMaximum() {
    return this.maximum;
  }
  public String getPattern() {
    return this.pattern;
  }
  public Boolean getRequired() {
    return this.required;
  }
  public boolean isRequired() {
    return this.required != null &&  this.required;
  }
  public static ValuesSchemaPropertyBuilder newBuilder() {
    return new ValuesSchemaPropertyBuilder();
  }
  public static ValuesSchemaPropertyBuilder newBuilderFromDefaults() {
    return new ValuesSchemaPropertyBuilder().withType("string").withMinimum(-2147483648).withMaximum(2147483647).withRequired(false);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ValuesSchemaProperty that = (ValuesSchemaProperty) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(description, that.description)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(minimum, that.minimum)) return false;

    if (!java.util.Objects.equals(maximum, that.maximum)) return false;

    if (!java.util.Objects.equals(pattern, that.pattern)) return false;

    if (!java.util.Objects.equals(required, that.required)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  description,  type,  minimum,  maximum,  pattern,  required,  super.hashCode());
  }
  
}
